//---------------------------------------------------------------- -o--
// MaterialUnitTest.java 
//
//
// HELPER METHODS--
//   setUp
//   tearDown
//
// TEST METHODS--
//   testCreateAndRetrieve
//
//
// @version 0.1 
//

import java.lang.*;
import java.io.*;
import java.util.*;

import junit.framework.*;
import org.junit.*;
import org.apache.commons.io.*;
import org.hamcrest.*;



//----------------------------------------------------------------- -o--
public class MaterialUnitTest extends TestCase
{
  HashMap<String, String>  gn2rn = null;



  //-------------------------------------------------------------- -o--
  // Test methods.
  //

  //------------------------------ -o-
  @Before
  protected void  setUp()  throws GTException
  {
    // Populate GalacticNumber map with valid entries.
    //
    gn2rn = new HashMap<String, String>();

    gn2rn.put("pith", "M");
    gn2rn.put("jara", "D");
    gn2rn.put("kroa", "C");
    gn2rn.put("soam", "L");
    gn2rn.put("dala", "X");
    gn2rn.put("zila", "V");
    gn2rn.put("gepk", "I");

    for (String rnKey : gn2rn.keySet()) {
      try {
        GalacticNumber.mapFromRomanNumber(rnKey, gn2rn.get(rnKey));
      } catch (GTException e) {
        throw new GTException(
          "TEST ERROR IN "+ getClass() +": GalacticNumber failed.");
      }
    }

  } // setUp()


  //------------------------------ -o-
  @After
  protected void  tearDown()
  {
    GalacticNumber.clear();

    gn2rn.clear();
    gn2rn = null;
  }


  //------------------------------ -o-
  @org.junit.Test
  public void  testCreateAndRetrieve()
  {
    String  existingMaterialUnit     = "Saturn";
    String  nonExistingMaterialUnit  = "Mercury";

    String  goodGalacticNumeral  = "pith pith jara kroa";
    String  badGalacticNumeral   = "zila grok spam";

    Boolean  constructorWorked;
    Float    expectedArabicNumeral,
             returnedArabicNumeral;


    // Bad input.
    //

    try {
      constructorWorked = true;
      MaterialUnit.mapFromGalacticAndArabicNumerals(
                                existingMaterialUnit, null, new Float(42));

    } catch (GTException e) {
      constructorWorked = false;
    }

    assertTrue( "MaterialUnit(string, null, 42) FAILED.", ! constructorWorked ); 


    //
    try {
      constructorWorked = true;
      MaterialUnit.mapFromGalacticAndArabicNumerals(
                                null, goodGalacticNumeral, new Float(42));

    } catch (GTException e) {
      constructorWorked = false;
    }

    assertTrue( 
      "MaterialUnit(null, string, 42) FAILED.", ! constructorWorked ); 


    //
    try {
      constructorWorked = true;
      MaterialUnit.mapFromGalacticAndArabicNumerals(
                                "", goodGalacticNumeral, new Float(42));

    } catch (GTException e) {
      constructorWorked = false;
    }

    assertTrue( 
      "MaterialUnit(\"\", goodGalacticNumeral, 42) FAILED.", 
      ! constructorWorked ); 


    try {
      constructorWorked = true;
      MaterialUnit.mapFromGalacticAndArabicNumerals(
                                existingMaterialUnit, "", new Float(42));

    } catch (GTException e) {
      constructorWorked = false;
    }

    assertTrue( 
      "MaterialUnit(existingMaterialUnit, \"\", 42) FAILED.", 
      ! constructorWorked ); 


    // Create and retrieve.
    //
    constructorWorked      = false;
    expectedArabicNumeral  = new Float(23.0 / 2600.0);
    returnedArabicNumeral  = new Float(0);

    try {
      MaterialUnit.mapFromGalacticAndArabicNumerals(
                existingMaterialUnit, goodGalacticNumeral, new Float(23));
      returnedArabicNumeral = 
                        MaterialUnit.asArabicNumeral(existingMaterialUnit);

      constructorWorked = true;

    } catch (GTException e) {
      constructorWorked = false;
    }

    assertTrue( 
      "MaterialUnit(existingMaterialUnit, goodGalacticNumeral, 23) EQUALS "
          + expectedArabicNumeral + ".",
      constructorWorked 
          && returnedArabicNumeral.equals(expectedArabicNumeral) ); 


    //
    assertTrue( 
      "MaterialUnit.isMaterial(existingMaterialUnit) SUCCEEDED.", 
      MaterialUnit.isMaterial(existingMaterialUnit) ); 
    
    assertTrue( 
      "MaterialUnit.isMaterial(nonExistingMaterialUnit) FAILED.", 
      ! MaterialUnit.isMaterial(nonExistingMaterialUnit) ); 


    //
    returnedArabicNumeral = MaterialUnit.asArabicNumeral(existingMaterialUnit);

    assertTrue( 
      "Retrieved MaterialUnit (" + existingMaterialUnit + ") EQUALS "
          + expectedArabicNumeral + ".",
      returnedArabicNumeral.equals(expectedArabicNumeral) );

  } // testCreateAndRetrieve()


} // class MaterialUnitTest

